@@ -32,11 +32,11 @@
 
 namespace folly {
 
-static_assert(IsConvertible<float>::value, "");
-static_assert(IsConvertible<int>::value, "");
-static_assert(IsConvertible<bool>::value, "");
-static_assert(IsConvertible<int>::value, "");
-static_assert(!IsConvertible<std::vector<int>>::value, "");
+static_assert(IsConvertible<float>::value);
+static_assert(IsConvertible<int>::value);
+static_assert(IsConvertible<bool>::value);
+static_assert(IsConvertible<int>::value);
+static_assert(!IsConvertible<std::vector<int>>::value);
 
 namespace detail {
 
