@@ -17,7 +17,6 @@
 #include <folly/detail/ThreadLocalDetail.h>
 
 #include <algorithm>
-#include <list>
 #include <mutex>
 #include <random>
 
@@ -70,18 +69,107 @@ bool ThreadEntrySet::basicSanity() const {
   auto const size = threadElements.size();
   rand_engine rng;
   std::uniform_int_distribution<size_t> dist{0, size - 1};
-  if (dist(rng) < constexpr_log2(size)) {
+  if (!(dist(rng) < constexpr_log2(size))) {
     return true;
   }
-  return //
-      threadElements.size() == entryToVectorSlot.size() &&
-      std::all_of(
-          entryToVectorSlot.begin(),
-          entryToVectorSlot.end(),
-          [&](auto const& kvp) {
-            return kvp.second < threadElements.size() &&
-                threadElements[kvp.second].threadEntry == kvp.first;
-          });
+  for (auto const& kvp : entryToVectorSlot) {
+    if (!(kvp.second < threadElements.size() &&
+          threadElements[kvp.second].threadEntry == kvp.first)) {
+      return false;
+    }
+  }
+  return true;
+}
+
+void ThreadEntrySet::clear() {
+  DCHECK(basicSanity());
+  entryToVectorSlot.clear();
+  threadElements.clear();
+}
+
+int64_t ThreadEntrySet::getIndexFor(ThreadEntry* entry) const {
+  auto iter = entryToVectorSlot.find(entry);
+  if (iter != entryToVectorSlot.end()) {
+    return static_cast<int64_t>(iter->second);
+  }
+  return -1;
+}
+
+void* ThreadEntrySet::getPtrForThread(ThreadEntry* entry) const {
+  auto index = getIndexFor(entry);
+  if (index < 0) {
+    return nullptr;
+  }
+  return threadElements[static_cast<size_t>(index)].wrapper.ptr;
+}
+
+bool ThreadEntrySet::contains(ThreadEntry* entry) const {
+  DCHECK(basicSanity());
+  return entryToVectorSlot.find(entry) != entryToVectorSlot.end();
+}
+
+bool ThreadEntrySet::insert(ThreadEntry* entry) {
+  DCHECK(basicSanity());
+  auto iter = entryToVectorSlot.find(entry);
+  if (iter != entryToVectorSlot.end()) {
+    // Entry already present. Sanity check and exit.
+    DCHECK_EQ(entry, threadElements[iter->second].threadEntry);
+    return false;
+  }
+  threadElements.emplace_back(entry);
+  auto idx = threadElements.size() - 1;
+  entryToVectorSlot[entry] = idx;
+  return true;
+}
+
+bool ThreadEntrySet::insert(const Element& element) {
+  DCHECK(basicSanity());
+  auto iter = entryToVectorSlot.find(element.threadEntry);
+  if (iter != entryToVectorSlot.end()) {
+    // Entry already present. Skip copying over element. Caller
+    // responsible for handling acceptability of this behavior.
+    DCHECK_EQ(element.threadEntry, threadElements[iter->second].threadEntry);
+    return false;
+  }
+  threadElements.push_back(element);
+  auto idx = threadElements.size() - 1;
+  entryToVectorSlot[element.threadEntry] = idx;
+  return true;
+}
+
+ThreadEntrySet::Element ThreadEntrySet::erase(ThreadEntry* entry) {
+  DCHECK(basicSanity());
+  auto iter = entryToVectorSlot.find(entry);
+  if (iter == entryToVectorSlot.end()) {
+    // Entry not present.
+    return Element{nullptr};
+  }
+  auto idx = iter->second;
+  DCHECK_LT(idx, threadElements.size());
+  entryToVectorSlot.erase(iter);
+  Element last = threadElements.back();
+  Element current = threadElements[idx];
+  if (idx != threadElements.size() - 1) {
+    threadElements[idx] = last;
+    entryToVectorSlot[last.threadEntry] = idx;
+  }
+  threadElements.pop_back();
+  DCHECK(basicSanity());
+  if (compressible()) {
+    compress();
+  }
+  DCHECK(basicSanity());
+  return current;
+}
+
+bool ThreadEntrySet::compressible() const {
+  // We choose a sufficiently-large multiplier so that there is no risk of a
+  // following insert growing the vector and then a following erase shrinking
+  // the vector, since that way lies non-amortized-O(N)-complexity costs for
+  // both insert and erase ops.
+  constexpr size_t const mult = 4;
+  auto& vec = threadElements;
+  return std::max(size_t(1), vec.size()) * mult <= vec.capacity();
 }
 
 bool ThreadEntry::cachedInSetMatchesElementsArray(uint32_t id) {
@@ -118,6 +206,60 @@ void ThreadEntrySet::compress() {
   entryToVectorSlot = std::move(newIndex);
 }
 
+/**
+ * We want to disable onThreadExit call at the end of shutdown, we don't care
+ * about leaking memory at that point.
+ *
+ * Otherwise if ThreadLocal is used in a shared library, onThreadExit may be
+ * called after dlclose().
+ *
+ * This class has one single static instance; however since it's so widely used,
+ * directly or indirectly, by so many classes, we need to take care to avoid
+ * problems stemming from the Static Initialization/Destruction Order Fiascos.
+ * Therefore this class needs to be constexpr-constructible, so as to avoid
+ * the need for this to participate in init/destruction order.
+ */
+class PthreadKeyUnregister {
+ public:
+  static constexpr size_t kMaxKeys = size_t(1) << 16;
+
+  ~PthreadKeyUnregister() {
+    // If static constructor priorities are not supported then
+    // ~PthreadKeyUnregister logic is not safe.
+#if !defined(__APPLE__) && !defined(_MSC_VER)
+    MSLGuard lg(lock_);
+    while (size_) {
+      pthread_key_delete(keys_[--size_]);
+    }
+#endif
+  }
+
+  static void registerKey(pthread_key_t key) { instance_.registerKeyImpl(key); }
+
+ private:
+  /**
+   * Only one global instance should exist, hence this is private.
+   * See also the important note at the top of this class about `constexpr`
+   * usage.
+   */
+  constexpr PthreadKeyUnregister() : lock_(), size_(0), keys_() {}
+
+  void registerKeyImpl(pthread_key_t key) {
+    MSLGuard lg(lock_);
+    if (size_ == kMaxKeys) {
+      throw_exception<std::logic_error>(
+          "pthread_key limit has already been reached");
+    }
+    keys_[size_++] = key;
+  }
+
+  MicroSpinLock lock_;
+  size_t size_;
+  pthread_key_t keys_[kMaxKeys];
+
+  static PthreadKeyUnregister instance_;
+};
+
 StaticMetaBase::StaticMetaBase(ThreadEntry* (*threadEntry)(), bool strict)
     : nextId_(1), threadEntry_(threadEntry), strict_(strict) {
   int ret = pthread_key_create(&pthreadKey_, &onThreadExit);
@@ -162,6 +304,38 @@ ThreadEntryList* StaticMetaBase::getThreadEntryList() {
   return threadEntryList;
 }
 
+ThreadEntry* StaticMetaBase::allocateNewThreadEntry() {
+  // If a thread is exiting, various cleanup handlers could
+  // end up triggering use of a ThreadLocal and (re)create a
+  // ThreadEntry. This is problematic since we don't know if the
+  // destructor specified in the pthreadKey_ has already been run
+  // for this StaticMeta or will run again. Such a newly created
+  // ThreadEntry could leak. The count incremented on threadEntryList
+  // could also cause all the list and other threadEntry objects used
+  // by this thread to leak.
+  // For now, debug assert that the thread is not exiting to keep the
+  // legacy behavior. The handling of this case needs to be improved
+  // as well.
+  DCHECK(!dying());
+  ThreadEntryList* threadEntryList = getThreadEntryList();
+  ThreadEntry* threadEntry = new ThreadEntry();
+
+  threadEntry->list = threadEntryList;
+  threadEntry->listNext = threadEntryList->head;
+  threadEntryList->head = threadEntry;
+
+  threadEntry->tid() = std::this_thread::get_id();
+  threadEntry->tid_os = folly::getOSThreadID();
+
+  // if we're adding a thread entry
+  // we need to increment the list count
+  // even if the entry is reused
+  threadEntryList->count++;
+
+  threadEntry->meta = this;
+  return threadEntry;
+}
+
 bool StaticMetaBase::dying() {
   return folly::detail::thread_is_dying();
 }
